##  Prerequisites
Before you enable discovered flows, ensure you meet the following requirements:
  * Configure and verify basic SAP landscape discovery. For setup instructions, see [Configuring the SAP Cloud ALM Integration](https://help.sap.com/docs/leanix/ea/sap-discovery-configuring-cloud-alm?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to integrate SAP LeanIX with SAP Cloud ALM to automate the discovery of SAP systems, services, and integration flows.").
  * Onboard SAP systems that participate in integration flows to SAP Cloud ALM.
For further assistance, [report a case![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Falm%2Fsap-cloud-alm%2Foperations%2Fexpert-portal%2Fintegration-monitoring%2Fint-mon-setup-support.html%3FanchorId%3Dsection_667953570 "https://support.sap.com/en/alm/sap-cloud-alm/operations/expert-portal/integration-monitoring/int-mon-setup-support.html?anchorId=section_667953570").
  * Enable Integration & Exception Monitoring in SAP Cloud ALM.
For more information, see [Integration & Exception Monitoring - Setup & Configuration![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Falm%2Fsap-cloud-alm%2Foperations%2Fexpert-portal%2Fintegration-monitoring%2Fint-mon-setup-support.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/en/alm/sap-cloud-alm/operations/expert-portal/integration-monitoring/int-mon-setup-support.html").
  * Activate data collection for the systems and services that you want to discover.
For more information, see [Activate Data Collection for a Service or System](https://help.sap.com/docs/cloud-alm/applicationhelp/im-configuring-services#activate-data-collection-for-a-service-or-system "https://help.sap.com/docs/cloud-alm/applicationhelp/im-configuring-services#activate-data-collection-for-a-service-or-system").
  * Enable flow discovery to start fetching flow objects with this integration.
For more information, see [Configuration: Flow Discovery](https://help.sap.com/docs/cloud-alm/applicationhelp/im-application-settings#configuration "https://help.sap.com/docs/cloud-alm/applicationhelp/im-application-settings#configuration").
  * After enabling flow discovery, allow 24-48 hours for initial flow data to be collected.
